from .Algoritmos import MCTS
from .Algoritmos import Minimax
from .Algoritmos import SOISMCTS
from .Algoritmos import MOISMCTS